@@ -1,5 +1,5 @@
 #' Comma formatter: format number with commas separating thousands.
-#' 
+#'
 #' @param ... other arguments passed on to \code{\link{format}}
 #' @param x a numeric vector to format
 #' @return a function with single paramater x, a numeric vector, that
@@ -20,9 +20,16 @@ comma <- function(x, ...) {
 }
 
 #' Currency formatter: round to nearest cent and display dollar sign.
-#' 
+#'
+#' The returned function will format a vector of values as currency.
+#' Values are rounded to the nearest cent, and cents are displayed if
+#' any of the values has a non-zero cents and the largest value is less
+#' than \code{largest_with_cents} which by default is 100000.
+#'
 #' @return a function with single paramater x, a numeric vector, that
 #'   returns a character vector
+#' @param largest_with_cents the value that all values of \code{x} must
+#'   be less than in order for the cents to be displayed
 #' @param x a numeric vector to format
 #' @export
 #' @examples
@@ -30,11 +37,18 @@ comma <- function(x, ...) {
 #' dollar_format()(c(1:10 * 10))
 #' dollar(c(100, 0.23, 1.456565, 2e3))
 #' dollar(c(1:10 * 10))
-dollar_format <- function() {
+#' dollar(10^(1:8))
+dollar_format <- function(largest_with_cents = 100000) {
   function(x) {
     x <- round_any(x, 0.01)
-    nsmall <- if (max(x, na.rm = TRUE) < 100) 2 else 0
-    str_c("$", format(x, nsmall = nsmall, trim = TRUE, big.mark = ","))    
+    if (max(x, na.rm = TRUE) < largest_with_cents &
+        !all(x == floor(x), na.rm = TRUE)) {
+      nsmall <- 2L
+    } else {
+      x <- round_any(x, 1)
+      nsmall <- 0L
+    }
+    paste0("$", format(x, nsmall = nsmall, trim = TRUE, big.mark = ",", scientific = FALSE, digits=1L))
   }
 }
 
@@ -43,7 +57,7 @@ dollar_format <- function() {
 dollar <- dollar_format()
 
 #' Percent formatter: multiply by one hundred and display percent sign.
-#' 
+#'
 #' @return a function with single paramater x, a numeric vector, that
 #'   returns a character vector
 #' @param x a numeric vector to format
@@ -55,7 +69,7 @@ dollar <- dollar_format()
 percent_format <- function() {
   function(x) {
     x <- round_any(x, precision(x) / 100)
-    str_c(comma(x * 100), "%")    
+    paste0(comma(x * 100), "%")
   }
 }
 #' @export
@@ -63,7 +77,7 @@ percent_format <- function() {
 percent <- percent_format()
 
 #' Scientific formatter.
-#' 
+#'
 #' @return a function with single paramater x, a numeric vector, that
 #'   returns a character vector
 #' @param digits number of significant digits to show
@@ -89,7 +103,7 @@ scientific <- function(x, digits = 3, ...) {
 }
 
 #' Parse a text label to produce expressions for plotmath.
-#' 
+#'
 #' @seealso \code{\link{plotmath}}
 #' @return a function with single paramater x, a character vector, that
 #'    returns a list of expressions
@@ -98,15 +112,15 @@ scientific <- function(x, digits = 3, ...) {
 #' parse_format()(c("alpha", "beta", "gamma"))
 parse_format <- function() {
   function(x) {
-    llply(as.character(x), function(x) parse(text = x, srcfile = NULL))    
+    llply(as.character(x), function(x) parse(text = x, srcfile = NULL))
   }
 }
 
 #' Add arbitrary expression to a label.
 #' The symbol that will be replace by the label value is \code{.x}.
-#' 
+#'
 #' @param expr expression to use
-#' @param format another format function to apply prior to mathematical 
+#' @param format another format function to apply prior to mathematical
 #'   transformation - this makes it easier to use floating point numbers in
 #'   mathematical expressions.
 #' @return a function with single paramater x, a numeric vector, that
@@ -123,12 +137,13 @@ math_format <- function(expr = 10 ^ .x, format = force) {
   subs <- function(x) {
     do.call("substitute", list(quoted, list(.x = as.name(x))))
   }
-  
+
   function(x) {
     x <- format(x)
     llply(x, subs)
   }
 }
+globalVariables(".x")
 
 #' Format labels after transformation.
 #'
@@ -142,7 +157,7 @@ math_format <- function(expr = 10 ^ .x, format = force) {
 #' tf(10 ^ 1:6)
 trans_format <- function(trans, format = scientific_format()) {
   if (is.character(trans)) trans <- match.fun(trans)
-  
+
   function(x) {
     x <- trans(x)
     format(x)
@@ -167,7 +182,7 @@ format_format <- function(...) {
 
 precision <- function(x) {
   rng <- range(x, na.rm = TRUE)
-  
+
   span <- if (zero_range(rng)) rng[1] else diff(rng)
   10 ^ floor(log10(span))
 }
