@@ -2,7 +2,6 @@
 #'
 #' @param name Name of colour palette.  One of:
 #'   \Sexpr[results=rd,stage=build]{scales:::dichromat_schemes()}
-#' @importFrom dichromat colorschemes
 #' @export
 #' @examples
 #' show_col(dichromat_pal("BluetoOrange.10")(10))
@@ -12,15 +11,16 @@
 #' cols <- dichromat_pal("DarkRedtoBlue.12")(12)
 #' show_col(gradient_n_pal(cols)(seq(0, 1, length = 30)))
 dichromat_pal <- function(name) {
-  if (!any(name == names(colorschemes))) {
-    stop("Palette name must be one of ", str_c(names(colorschemes), collapse = ", "), call. = FALSE)
+  if (!any(name == names(dichromat::colorschemes))) {
+    stop("Palette name must be one of ",
+      paste0(names(dichromat::colorschemes), collapse = ", "), call. = FALSE)
   }
-  
-  pal <- colorschemes[[name]]
+
+  pal <- dichromat::colorschemes[[name]]
   function(n) pal[seq_len(n)]
 }
 
 
 dichromat_schemes <- function() {
-  str_c("\\code{", names(colorschemes), "}", collapse = ", ")
-}
\ No newline at end of file
+  paste0("\\code{", names(dichromat::colorschemes), "}", collapse = ", ")
+}
